Exception: JWT::VerificationError

Inherits:
SignatureError show all
Defined in:
lib/jwt/error.rb

Overview

The VerificationError class is raised when the signature of a token does not match the one calculated from the signing input.

Direct Known Subclasses

VerificationKeyError