Exception: JWT::VerificationError
- Inherits:
-
SignatureError
- Object
- StandardError
- Error
- DecodeError
- TokenError
- SignatureError
- JWT::VerificationError
- Defined in:
- lib/jwt/error.rb
Overview
The VerificationError class is raised when the signature of a token does not match the one calculated from the signing input.